import superagent from 'superagent';

import config from './config';

const methods = ['get', 'post'];

const formatUrl = (type, path) => {
  const adjustedPath = path[0] !== '/' ? `/${path}` : path;
  if (type === 1) {
    return `${config.AUTH_URL}${adjustedPath}`;
  }
  return `${config.API_URL}${adjustedPath}`;
};

export default class Client {
  /**
   * type: 1 认证，2 API
   */
  constructor(type) {
    methods.forEach(method => {
      this[method] = (path, { params, data, token } = {}) => new Promise((resolve, reject) => {
        const request = superagent[method](formatUrl(type, path));

        if (params) {
          request.query(params);
        }

        if (data) {
          request.send(data);
        }

        if (token) {
          request.set('Authorization', token);
        }

        request.end((err, { body } = {}) => {
          if (err) {
            reject(body || err);
          } else {
            resolve(body);
          }
        });
      });
    });
  }
}
